svn commit: r303122 - head/usr.bin/gcore

Conrad E. Meyer cem at FreeBSD.org
Thu Jul 21 00:53:16 UTC 2016


Author: cem
Date: Thu Jul 21 00:53:14 2016
New Revision: 303122
URL: https://svnweb.freebsd.org/changeset/base/303122

Log:
  Mirror r303120 to gcore
  
  Sponsored by:	EMC / Isilon Storage Division

Modified:
  head/usr.bin/gcore/elfcore.c

Modified: head/usr.bin/gcore/elfcore.c
==============================================================================
--- head/usr.bin/gcore/elfcore.c	Thu Jul 21 00:52:53 2016	(r303121)
+++ head/usr.bin/gcore/elfcore.c	Thu Jul 21 00:53:14 2016	(r303122)
@@ -95,7 +95,7 @@ typedef void* (*notefunc_t)(void *, size
 
 static void cb_put_phdr(vm_map_entry_t, void *);
 static void cb_size_segment(vm_map_entry_t, void *);
-static void each_writable_segment(vm_map_entry_t, segment_callback,
+static void each_dumpable_segment(vm_map_entry_t, segment_callback,
     void *closure);
 static void elf_detach(void);	/* atexit() handler. */
 static void *elf_note_fpregset(void *, size_t *);
@@ -206,7 +206,7 @@ elf_coredump(int efd __unused, int fd, p
 	/* Size the program segments. */
 	seginfo.count = 0;
 	seginfo.size = 0;
-	each_writable_segment(map, cb_size_segment, &seginfo);
+	each_dumpable_segment(map, cb_size_segment, &seginfo);
 
 	/*
 	 * Build the header and the notes using sbuf and write to the file.
@@ -277,7 +277,7 @@ elf_coredump(int efd __unused, int fd, p
 }
 
 /*
  * A callback for each_writable_segment() to write out the segment's
  * program header entry.
  */
 static void
@@ -307,7 +307,7 @@ cb_put_phdr(vm_map_entry_t entry, void *
 }
 
 /*
  * A callback for each_writable_segment() to gather information about
  * the number of segments and their total size.
  */
 static void
@@ -325,7 +325,7 @@ cb_size_segment(vm_map_entry_t entry, vo
  * data.
  */
 static void
-each_writable_segment(vm_map_entry_t map, segment_callback func, void *closure)
+each_dumpable_segment(vm_map_entry_t map, segment_callback func, void *closure)
 {
 	vm_map_entry_t entry;
 
@@ -497,7 +497,7 @@ elf_puthdr(pid_t pid, vm_map_entry_t map
 	/* All the writable segments from the program. */
 	phc.phdr = phdr;
 	phc.offset = segoff;
-	each_writable_segment(map, cb_put_phdr, &phc);
+	each_dumpable_segment(map, cb_put_phdr, &phc);
 }
 
 /*
@@ -277,7 +277,7 @@ elf_coredump(int efd __unused, int fd, p
 
 /*
- * A callback for each_writable_segment() to write out the segment's
+ * A callback for each_dumpable_segment() to write out the segment's
  * program header entry.
  */
@@ -307,7 +307,7 @@ cb_put_phdr(vm_map_entry_t entry, void *
 
 /*
- * A callback for each_writable_segment() to gather information about
+ * A callback for each_dumpable_segment() to gather information about
  * the number of segments and their total size.
  */


More information about the svn-src-all mailing list